@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bug;
-$BZ::Client::Bug::VERSION = '2.0_8';
+$BZ::Client::Bug::VERSION = '2.0_9';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bug.html
@@ -103,26 +103,13 @@ sub search {
 
 sub create {
     my($class, $client, $params) = @_;
-    $client->log('debug', __PACKAGE__ . '::create: Creating');
-    my $result = $class->api_call($client, 'Bug.create', $params);
-    my $id = $result->{'id'};
-    if (!$id) {
-        $class->error($client, 'Invalid reply by server, expected bug ID.');
-    }
-    $client->log('debug', __PACKAGE__ . "::create: Made $id");
-    return $id
+    return _create($client, 'Bug.create', $params);
 }
 
 sub update {
     my($class, $client, $params) = @_;
-    $client->log('debug', __PACKAGE__ . '::update: Updating');
-    my $result = $class->api_call($client, 'Bug.update', $params);
-    my $bugs = $result->{'bugs'};
-    if (!$bugs || 'ARRAY' ne ref($bugs)) {
-        $class->error($client, 'Invalid reply by server, expected array of bug details.');
-    }
-    $client->log('debug', __PACKAGE__ . '::update: Updated stuff');
-    return wantarray ? @$bugs : $bugs
+    return _returns_array($client, 'Bug.update', $params, 'bugs');
+
 }
 
 sub update_see_also {
@@ -335,7 +322,7 @@ BZ::Client::Bug - Client side representation of a bug in Bugzilla
 
 =head1 VERSION
 
-version 2.0_8
+version 2.0_9
 
 =head1 SYNOPSIS
 
@@ -717,6 +704,8 @@ You do not have access to the bug_id you specified.
 
 =head2 search
 
+FIXME
+
  @bugs = BZ::Client::Bug->search( $client, \%params );
  $bugs = BZ::Client::Bug->search( $client, \%params );
 
