@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Bug::Attachment;
-$BZ::Client::Bug::Attachment::VERSION = '2.0_8';
+$BZ::Client::Bug::Attachment::VERSION = '2.0_9';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Bug.html
@@ -59,15 +59,10 @@ sub add {
 
 sub update {
     my($class, $client, $params) = @_;
-    $client->log('debug', 'BZ::Client::Bug::add: Creating');
-    my $result = $class->api_call($client, 'Bug.update_attachment', $params);
-    my $attachments = $result->{'attachments'};
-    if (!$attachments || 'ARRAY' ne ref($attachments)) {
-        $class->error($client, 'Invalid reply by server, expected arayy of attachment changes.');
-    }
-    return $attachments
+    return _returns_array($client, 'Bug.update_attachment', $params, 'attachments');
 }
 
+
 ## rw methods
 
 sub id {
@@ -192,7 +187,7 @@ BZ::Client::Bug::Attachment - Client side representation of an Attachment to a B
 
 =head1 VERSION
 
-version 2.0_8
+version 2.0_9
 
 =head1 SYNOPSIS
 
