@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Classification;
-$BZ::Client::Classification::VERSION = '2.0_8';
+$BZ::Client::Classification::VERSION = '2.0_9';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Classificaton.html
@@ -16,14 +16,10 @@ use parent qw( BZ::Client::API );
 
 sub get {
     my($class, $client, $params) = @_;
-    my $result = $class->api_call($client, 'Classification.get', $params);
-    my $classifications = $result->{'classifications'};
-    if (!$classifications || 'ARRAY' ne ref($classifications)) {
-        $class->error($client, 'Invalid reply by server, expected array of classifications.');
-    }
-    return wantarray ? @$classifications : $classifications
+    return _returns_array($client, 'Classification.get', $params, 'classifications');
 }
 
+
 1;
 
 __END__
@@ -38,7 +34,7 @@ BZ::Client::Classification - Client side representation of a Classifications in
 
 =head1 VERSION
 
-version 2.0_8
+version 2.0_9
 
 =head1 SYNOPSIS
 
