@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Component;
-$BZ::Client::Component::VERSION = '2.0_8';
+$BZ::Client::Component::VERSION = '2.0_9';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Component.html
@@ -16,36 +16,17 @@ use parent qw( BZ::Client::API );
 
 sub create {
     my($class, $client, $params) = @_;
-    $client->log('debug', __PACKAGE__ . '::create: Creating');
-    my $result = $class->api_call($client, 'Component.create', $params);
-    my $id = $result->{'id'};
-    if (!$id) {
-        $class->error($client, 'Invalid reply by server, expected component ID.');
-    }
-    $client->log('debug', __PACKAGE__ . "::create: Made $id");
-    return $id
+    return _create($client, 'Component.create', $params);
 }
 
 sub update {
     my($class, $client, $params) = @_;
-    $client->log('debug', __PACKAGE__ . '::update: Updating');
-    my $result = $class->api_call($client, 'Component.update', $params);
-    my $components = $result->{'components'};
-    if (!$components || 'ARRAY' ne ref($components)) {
-        $class->error($client, 'Invalid reply by server, expected array of components details.');
-    }
-    $client->log('debug', __PACKAGE__ . '::update: Updated stuff');
-    return wantarray ? @$components : $components
+    return _returns_array($client, 'Component.update', $params, 'components');
 }
 
 sub delete {
     my($class, $client, $params) = @_;
-    my $result = $class->api_call($client, 'Component.delete', $params);
-    my $components = $result->{'components'};
-    if (!$components || 'ARRAY' ne ref($components)) {
-        $class->error($client, 'Invalid reply by server, expected array of components.');
-    }
-    return wantarray ? @$components : $components
+    return _returns_array($client, 'Component.delete', $params, 'components');
 }
 
 1;
@@ -62,7 +43,7 @@ BZ::Client::Component - Client side representation of Product Components in Bugz
 
 =head1 VERSION
 
-version 2.0_8
+version 2.0_9
 
 =head1 SYNOPSIS
 
