@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Product;
-$BZ::Client::Product::VERSION = '2.0_8';
+$BZ::Client::Product::VERSION = '2.0_9';
 use parent qw( BZ::Client::API );
 
 # See https://www.bugzilla.org/docs/tip/en/html/api/Bugzilla/WebService/Product.html
@@ -15,26 +15,12 @@ use parent qw( BZ::Client::API );
 
 sub create {
     my($class, $client, $params) = @_;
-    $client->log('debug', __PACKAGE__ . '::create: Creating');
-    my $result = $class->api_call($client, 'Product.create', $params);
-    my $id = $result->{'id'};
-    if (!$id) {
-        $class->error($client, 'Invalid reply by server, expected bug ID.');
-    }
-    $client->log('debug', __PACKAGE__ . "::create: Made $id");
-    return $id
+    return _create($client, 'Product.create', $params);
 }
 
 sub update {
     my($class, $client, $params) = @_;
-    $client->log('debug', __PACKAGE__ . '::update: Updating');
-    my $result = $class->api_call($client, 'Product.update', $params);
-    my $products = $result->{'products'};
-    if (!$products || 'ARRAY' ne ref($products)) {
-        $class->error($client, 'Invalid reply by server, expected array of products details.');
-    }
-    $client->log('debug', __PACKAGE__ . '::update: Updated stuff');
-    return wantarray ? @$products : $products
+    return _returns_array($client, 'Product.update', $params, 'components');
 }
 
 # convenience function
@@ -225,7 +211,7 @@ BZ::Client::Product - Client side representation of a product in Bugzilla
 
 =head1 VERSION
 
-version 2.0_8
+version 2.0_9
 
 =head1 SYNOPSIS
 
@@ -247,7 +233,7 @@ This section lists the class methods, which are available in this module.
 
  $id = BZ::Client::Product->create( $client, \%params );
 
-This allows you to create a new product in Bugzilla.
+This allows you to create a new Product in Bugzilla.
 
 Marked as experimental as of Bugzilla 5.0.
 
@@ -335,7 +321,7 @@ You must specify a version for this product.
 
  $id = BZ::Client::Product->update( $client, \%params );
 
-This allows you to update a product in Bugzilla.
+This allows you to update a Group in Bugzilla.
 
 As of Bugzilla 5.0. this is marked as experimental.
 
